# ScriptRunner Connect Managed API for Salesforce
Managed API for Salesforce is an API Client for Salesforce by [Adaptavist](https://www.adaptavist.com/). You can read more about Managed APIs [here](https://docs.adaptavist.com/src/managed-apis).

This is [ScriptRunner Connect](https://scriptrunnerconnect.com) runtime specific version of the Managed API (with `sr-connect` suffix). If you want to use Managed API in any other runtime, have a look at the [runtime agnostic version](https://www.npmjs.com/package/@managed-api/salesforce-v57-core).

# Supported API calls
- [fetch](https://docs.adaptavist.com/src/managed-apis/managed-api-abstractions)
- sObject
    - [getBasicInformation](https://developer.salesforce.com/docs/atlas.en-us.api_rest.meta/api_rest/resources_sobject_basic_info_get.htm)
    - Row
        - [getRecord](https://developer.salesforce.com/docs/atlas.en-us.api_rest.meta/api_rest/resources_sobject_retrieve_get.htm)
        - [updateRecord](https://developer.salesforce.com/docs/atlas.en-us.api_rest.meta/api_rest/resources_sobject_retrieve_patch.htm)
        - [deleteRecord](https://developer.salesforce.com/docs/atlas.en-us.api_rest.meta/api_rest/resources_sobject_retrieve_delete.htm)

# Constructing Managed API
In ScriptRunner Connect a Managed API is constructed for you, but if you need to construct it manually, here's how you can do it:
```typescript
import { SalesforceApi } from '@managed-api/salesforce-v57-sr-connect';

export default async function() {
    const api = new SalesforceApi('API_CONNECTION_ID');
}
```

# Contact
Feel free to drop ideas, suggestions or improvements into our [Community hub](https://loop.scriptrunnerhq.com/c/integration-forum).

# Changelog

* 2.1.0
    - Removed non-empty body from HEAD requests.

* 2.0.0
    - `Breaking change:` URL and query string parameters are now URL encoded, meaning if you encoded them explicitly before you have to remove your own encoding, otherwise they will get double encoded.

* 0.1.0
    - Added support for the following sObject methods:
        * [List organization members](https://developer.salesforce.com/docs/atlas.en-us.api_rest.meta/api_rest/resources_sobject_basic_info_get.htm) that can be used as `sObject.getBasicInformation` or `All.getSObjectBasicInformation`.
    - Added support for the following sObject.Row methods:
        * [List organization members](https://developer.salesforce.com/docs/atlas.en-us.api_rest.meta/api_rest/resources_sobject_retrieve_get.htm) that can be used as `sObject.Row.getRecord` or `All.getSObjectRowRecord`.
        * [List organization members](https://developer.salesforce.com/docs/atlas.en-us.api_rest.meta/api_rest/resources_sobject_retrieve_patch.htm) that can be used as `sObject.Row.updateRecord` or `All.updateSObjectRowRecord`.
        * [List organization members](https://developer.salesforce.com/docs/atlas.en-us.api_rest.meta/api_rest/resources_sobject_retrieve_delete.htm) that can be used as `sObject.Row.deleteRecord` or `All.deleteSObjectRowRecord`.

Copyright Adaptavist 2023 (c) All rights reserved